Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5348)

Unified Diff: chrome/common/notification_type.h

Issue 46094: Fix our handling of mixed SSL / non-SSL content.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/common/notification_type.h
===================================================================
--- chrome/common/notification_type.h (revision 11701)
+++ chrome/common/notification_type.h (working copy)
@@ -132,16 +132,27 @@
// are provided.
RESOURCE_RECEIVED_REDIRECT,
// The SSL state of a page has changed somehow. For example, if an insecure
// resource is loaded on a secure page. Note that a toplevel load commit
// will also update the SSL state (since the NavigationEntry is new) and
// this message won't always be sent in that case.
//
// The source will be the navigation controller associated with the load.
- // There are no details. The entry changed will be the active entry of the
+ // There are no details. The entry changed will be the active entry of the
// controller.
- SSL_STATE_CHANGED,
+ SSL_VISIBLE_STATE_CHANGED,
+ // The SSL state of the browser has changed in some internal way. For
+ // example, the user might have explicitly allowed some broken certificate
+ // or a secure origin might have included some insecure content. Listen to
+ // this notifiation if you need to keep track of our internal SSL state.
+ //
+ // The source will be the navigation controller associated with the state
+ // change. There are no details.
+ SSL_INTERNAL_STATE_CHANGED,
+
// Download start and stop notifications. Stop notifications can occur on
// both normal completion or via a cancel operation.
DOWNLOAD_START, DOWNLOAD_STOP,
@@ -132,16 +132,27 @@
// are provided.
RESOURCE_RECEIVED_REDIRECT,
- // The SSL state of a page has changed somehow. For example, if an insecure
- // resource is loaded on a secure page. Note that a toplevel load commit
- // will also update the SSL state (since the NavigationEntry is new) and
- // this message won't always be sent in that case.
+ // The SSL state of a page has changed in some visible way. For example,
+ // if an insecure resource is loaded on a secure page. Note that a
+ // toplevel load commit will also update the SSL state (since the
+ // NavigationEntry is new) and this message won't always be sent in that
+ // case. Listen to this notification if you need to refresh SSL-related UI
+ // elements.
//
// The source will be the navigation controller associated with the load.

Powered by Google App Engine
This is Rietveld 408576698